@@ -1,17 +1,13 @@
 # This Python file uses the following encoding: utf-8
 import sys
 import json
-
-from ww import f
+from datetime import datetime
+import webbrowser
 
 from PySide2.QtWidgets import *
-
 from PySide2.QtGui import QKeySequence
 from PySide2.QtCore import Qt
 
-from .spec import *
-from .validator import validate
-
 from .gui_lib.mainwindow import Ui_MainWindow
 from .gui_lib.devicewidget import Ui_DeviceWidget
 from .gui_lib.devicedetails import Ui_DeviceDetails
@@ -30,7 +26,8 @@ from .gui_lib.cmddetails import Ui_CmdDetails
 from .gui_lib.cmdarg import Ui_CmdArg
 from .gui_lib.enumvalue import Ui_EnumValue
 
-from datetime import datetime
+from .spec import *
+from .validator import validate
 
 
 class FakeParent:
@@ -83,7 +80,6 @@ class NodeDetails(QWidget):
         self.gui.reload()
 
     def delete(self):
-        print("delete", self.node)
         r = self.gui.spec.rm_node(self.node)
         self.setVisible(False)
         self.parent.setVisible(False)
@@ -91,7 +87,6 @@ class NodeDetails(QWidget):
 
     def reload(self):
         for child in self.children:
-            print("\t",child, flush=True)
             child.reload()
 
         for att, get_f, set_f in self.atts:
@@ -289,7 +284,6 @@ class CmdDetails(NodeDetails):
         if arg == None or arg == False:
             arg = Argument()
         
-        print("add argument")
         self.node.args[arg.name] = arg
         arg_widget = ArgDetails(self.gui, arg, FakeParent())
         self.children.append(arg_widget)
@@ -324,7 +318,6 @@ class CmdWidget(QWidget):
 
     def reload(self):
         for child in self.children:
-            print("\t", child, flush=True)
             child.reload()
 
     def add_cmd(self, cmd=None):
@@ -401,7 +394,6 @@ class CfgWidget(QWidget):
 
     def reload(self):
         for child in self.children:
-            print("\t", child, flush=True)
             child.reload()
 
     def add_cfg(self, cfg=None):
@@ -495,31 +487,6 @@ class DeviceWidget(NodeDetails):
         self.details_button.clicked.connect(self.open_details)
 
 
-class LogDetails(NodeDetails):
-    def load_atts(self, ui, node):
-        self.atts = [
-            (ui.idEdit, node.get_id, node.set_id),
-            (ui.nameEdit, node.get_name, node.set_name),
-            (ui.n_argsEdit, node.get_n_args, node.set_n_args),
-            (ui.commentEdit, node.get_comment, node.set_comment),
-            (ui.stringEdit, node.get_string, node.set_string),
-        ]
-
-    def __init__(self, gui, node, parent):
-        NodeDetails.__init__(self, gui, node, parent)
-
-        self.ui = Ui_LogDetails()
-        self.ui.setupUi(self)
-
-        self.load_atts(self.ui, node)
-        self.connect_atts()
-
-        self.ui.logDeleteButton.clicked.connect(self.delete)
-
-        self.reload()
-        self.setVisible(True)
-
-        self.children = []
 
 class EnumValueDetails(NodeDetails):
     def load_atts(self, ui, node):
@@ -568,25 +535,52 @@ class EnumDetails(NodeDetails):
         self.children = []
 
         self.ui.valueAddButton.clicked.connect(self.add_value)
-
+        
         for enum_value in node.enumeration.values():
             self.add_value(enum_value)
 
     def add_value(self, enum_value=None):
         if enum_value == None or enum_value == False:
             enum_value = EnumValue()
+            self.node.enumeration[enum_value.name] = enum_value
 
-        self.node.enumeration[enum_value.name] = enum_value
         enum_widget = EnumValueDetails(self.gui, enum_value, FakeParent())
         self.children.append(enum_widget)
         self.ui.EnumValueContents.addWidget(enum_widget)
-        
+
     def save(self):
         for child in self.children:
             child.save()
 
         self.gui.reload()
 
+
+class LogDetails(NodeDetails):
+    def load_atts(self, ui, node):
+        self.atts = [
+            (ui.idEdit, node.get_id, node.set_id),
+            (ui.nameEdit, node.get_name, node.set_name),
+            (ui.n_argsEdit, node.get_n_args, node.set_n_args),
+            (ui.commentEdit, node.get_comment, node.set_comment),
+            (ui.stringEdit, node.get_string, node.set_string),
+        ]
+
+    def __init__(self, gui, node, parent):
+        NodeDetails.__init__(self, gui, node, parent)
+
+        self.ui = Ui_LogDetails()
+        self.ui.setupUi(self)
+
+        self.load_atts(self.ui, node)
+        self.connect_atts()
+
+        self.ui.logDeleteButton.clicked.connect(self.delete)
+
+        self.reload()
+        self.setVisible(True)
+
+        self.children = []
+
 class LogWidget(QWidget):
     def __init__(self, gui, parent):
         self.Window = True
@@ -608,12 +602,11 @@ class LogWidget(QWidget):
         self.ui.addLogButton.clicked.connect(self.add_log)
         for log in self.parent.logs.values():
             self.add_log(log)
-
+    
     def reload(self):
         return
 
     def save(self):
-        print("Save log")
         for child in self.children:
             child.save()
 
@@ -654,6 +647,9 @@ class EnumWidget(QWidget):
         for child in self.children:
             child.reload()
 
+        for att, get_f, set_f in self.atts:
+            att.setText(str(get_f()))
+
         return
 
     def save(self):
@@ -665,7 +661,6 @@ class EnumWidget(QWidget):
     def add_enum(self, enum=None):
         if enum == None or enum == False:
             enum = Enum()
-
         self.parent.enums[enum.name] = enum
         enum_widget = EnumDetails(self.gui, enum, FakeParent())
         self.ui.enumContents.addWidget(enum_widget)
@@ -673,18 +668,33 @@ class EnumWidget(QWidget):
 
 class Gui(QMainWindow):
     def __init__(self, logger):
-        self.logger = logger
         QMainWindow.__init__(self)
         self.ui = Ui_MainWindow()
         self.ui.setupUi(self)
+        
+        self.logger = logger
+
+        self.spec = Spec()
+        self.children = []
+        
+        self.connect_buttons()
+        self.config_shortcuts()
+
+        self.log_widget = None
+        self.enum_widget = None
+    
+    def connect_buttons(self):
+        def fcp_help(link):
+            webbrowser.open(link)
 
         self.ui.actionOpen.triggered.connect(self.open_json)
         self.ui.actionSave.triggered.connect(self.save_json)
         self.ui.actionValidate.triggered.connect(self.validate)
+        self.ui.action_software10e_help.triggered.connect(lambda : fcp_help("https://projectofst.gitlab.io/software10e/docs/fcp/"))
+        self.ui.action_fcp_help.triggered.connect(lambda : fcp_help("https://fcp-core.readthedocs.io/en/latest/"))
+        self.ui.addButton.clicked.connect(self.add_device)
 
-        self.spec = Spec()
-        self.children = []
-
+    def config_shortcuts(self):
         shortcutSave = QShortcut(QKeySequence(Qt.CTRL + Qt.Key_S), self)
         shortcutSave.setContext(Qt.ApplicationShortcut)
         shortcutSave.activated.connect(self.save_json)
@@ -693,25 +703,6 @@ class Gui(QMainWindow):
         shortcutOpen.setContext(Qt.ApplicationShortcut)
         shortcutOpen.activated.connect(self.open_json)
 
-        self.ui.addButton.clicked.connect(self.add_device)
-
-        self.log_widget = None
-        self.enum_widget = None
-
-    def open_log_widget(self, checked):
-        if self.log_widget is None:
-            print("log not opened")
-            return
-
-        self.log_widget.setVisible(checked)
-
-    def open_enum_widget(self, checked):
-        if self.enum_widget is None:
-            print("enum not opened")
-            return
-        
-        self.enum_widget.setVisible(checked)
-
     def validate(self):
         msg = QMessageBox(self)
         msg.setStandardButtons(QMessageBox.Ok)
@@ -733,7 +724,7 @@ class Gui(QMainWindow):
 
             r = self.spec.add_device(device)
             if r == False:
-                print("Failed to create device")
+                self.logger.error("Failed to create device")
                 return
 
         dev_widget = DeviceWidget(
@@ -763,7 +754,7 @@ class Gui(QMainWindow):
             msg = QMessageBox(self)
             msg.setStandardButtons(QMessageBox.Ok)
             msg.setIcon(QMessageBox.Warning)
-            msg.setText(f("{filename} is not a valid filename"))
+            msg.setText(f"{filename} is not a valid filename")
             msg.show()
             return
 
@@ -776,10 +767,11 @@ class Gui(QMainWindow):
             msg = QMessageBox(self)
             msg.setStandardButtons(QMessageBox.Ok)
             msg.setIcon(QMessageBox.Warning)
-            msg.setText(f("'{filename}' is not a valid filename"))
+            msg.setText(f"'{filename}' is not a valid filename")
             msg.show()
             return
-
+        
+        print(filename)
         with open(filename) as f:
             j = json.loads(f.read())
 
@@ -793,19 +785,20 @@ class Gui(QMainWindow):
         self.log_widget = LogWidget(self, self.spec)
         self.log_widget.setVisible(True)
         self.ui.logDetailsLayout.addWidget(self.log_widget)
+        self.children.append(self.log_widget)
         self.enum_widget = EnumWidget(self, self.spec)
         self.enum_widget.setVisible(True)
         self.ui.enumDetailsLayout.addWidget(self.enum_widget)
+        self.children.append(self.enum_widget)
 
     def reload(self):
         for node in self.children:
-            print(node, flush=True)
             node.reload()
 
         self.spec.normalize()
 
 
-def gui(logger, file):
+def gui(file, logger):
     app = QApplication([])
     window = Gui(logger)
     if file != None and file != "":
